@@ -77,16 +77,16 @@ ChewingEditor::~ChewingEditor()
 
 void ChewingEditor::execFileDialog(DialogType type)
 {
-    qDebug() << "dialogType_ = " << dialogType_;
-
     dialogType_ = type;
 
+    qDebug() << "dialogType_ = " << dialogType_;
+
     switch (dialogType_) {
     case DIALOG_IMPORT:
         fileDialog_->setWindowTitle(tr("Import"));
         fileDialog_->setAcceptMode(QFileDialog::AcceptOpen);
         fileDialog_->setFileMode(QFileDialog::ExistingFile);
-        fileDialog_->setConfirmOverwrite(false);
+        fileDialog_->setOption(QFileDialog::DontConfirmOverwrite, true);
         fileDialog_->selectFile("");
         break;
 
@@ -94,7 +94,7 @@ void ChewingEditor::execFileDialog(DialogType type)
         fileDialog_->setWindowTitle(tr("Export"));
         fileDialog_->setAcceptMode(QFileDialog::AcceptSave);
         fileDialog_->setFileMode(QFileDialog::AnyFile);
-        fileDialog_->setConfirmOverwrite(true);
+        fileDialog_->setOption(QFileDialog::DontConfirmOverwrite, false);
         fileDialog_->selectFile("chewing.json");
         break;
 
@@ -125,8 +125,10 @@ void ChewingEditor::finishFileSelection(const QString& file)
     switch (dialogType_) {
     case DIALOG_IMPORT:
         // Do nothing after the first trigger
-        if(import_count++ == 1)
+        if (import_count == 0) {
             importUserphrase(file);
+            import_count++;
+        }
 
         qDebug() << "import_count = " << import_count;
 
@@ -191,6 +193,8 @@ void ChewingEditor::showAbout()
 
 void ChewingEditor::showDeleteConfirmWindow()
 {
+    if(ui_.get()->userphraseView->selectionModel()->selectedIndexes().size() == 0) return;
+    
     QString text = tr("Do you want to delete this phrase?");
 
     QMessageBox deleteBox(this);
